Reference
----------

.. [LIANA] Dimitrov, D., Türei, D., Garrido-Rodriguez, M., Burmedi, P.L., Nagai, J.S., Boys, C.,
    Ramirez Flores, R.O., Kim, H., Szalai, B., Costa, I.G. and Valdeolivas, A., 2022. Comparison of
    methods and resources for cell-cell communication inference from single-cell RNA-Seq data.
    Nature Communications, 13(1), pp.1-13.
    
.. [Omnipath] Türei, D., Valdeolivas, A. et al. (2020), **Integrated intra- and intercellular signaling 
    knowledge for multicellular omics analysis.**, `Molecular Systems Biology 17:e9923. <https://doi.org/10.15252/msb.20209923>`__.